@@ -6,14 +6,13 @@ oaipmh-validator.pl -- OAI-PMH Data Provider Validator
 
 =head1 SYNOPSIS
 
-oaipmh-validator.pl [-s] [-h] [[baseURL]]
+oaipmh-validator.pl [[baseURL]]
 
-Will run validator on baseURL (and optionally additional baseURLs) with
-progress 
+Will run validator on and OAI-PMH data provider at baseURL. Will 
+show progress of the validation.
 
-  -s   allow HTTPS base URL (not part of the OAI-PMH specification)
-  -v   verbose debugging output
-  -h   this help
+  -d  show debugging output
+  -h  this help
 
 =cut
 
@@ -27,16 +26,17 @@ use Getopt::Std;
 use Pod::Usage;
 
 my %opt;
-(getopts('dsh',\%opt)&&!$opt{h}) || pod2usage();
+(getopts('dh',\%opt)&&!$opt{h}) || pod2usage();
 
 foreach my $base_url (@ARGV) {
     print "\n# RUNNING VALIDATION FOR $base_url\n";
-    my $val = HTTP::OAIPMH::Validator->new( base_url=>$base_url, allow_https=>$opt{s}, debug=>$opt{d} );
+    my $val = HTTP::OAIPMH::Validator->new( base_url=>$base_url,
+                                            debug=>$opt{d} );
     $val->log->fh(\*STDOUT); $|=1;
     try {
-	$val->run_complete_validation;
+        $val->run_complete_validation;
     } catch {
-	warn "\noops, validation didn't run to completion: $_\n";
+        warn "\noops, validation didn't run to completion: $_\n";
     };
     print "\n## Validation status of data provider ".$val->base_url." is ".$val->status."\n";
 }
